pub enum SecretboxError {
Truncated,
TagMismatch,
Random(RandomError),
}Expand description
crypto_secretbox can fail for reasons beyond a wrong key.
Variants
Truncated
The input to open is shorter than a nonce plus a tag (48 bytes) - too short to have
ever been produced by seal.
TagMismatch
Authentication failed: wrong key, or sealed was tampered with.
Random(RandomError)
The OS CSPRNG failed while generating a nonce (see crate::randombytes).