pub fn randombytes_buf(buf: &mut [u8]) -> Result<(), RandomError>Expand description
Fills buf with cryptographically secure random bytes from the OS CSPRNG.
Errors
Returns RandomError if the OS CSPRNG is unavailable or fails.
pub fn randombytes_buf(buf: &mut [u8]) -> Result<(), RandomError>Fills buf with cryptographically secure random bytes from the OS CSPRNG.
Returns RandomError if the OS CSPRNG is unavailable or fails.